@@ -31,7 +31,7 @@ class Monster:
             "Health": self.health,
             "Energy": self.energy,
             "Sanity": self.sanity,
-            "Time Stamp": self.timestamp,
+            "Timestamp": self.timestamp,
         }
 
     def __repr__(self):
